# QuickNotes Application Specifications

This document provides an overview of the QuickNotes application specifications. QuickNotes is a personal knowledge management system that allows users to create and manage notes, read later items, and RSS/Atom feeds.

## Overview

QuickNotes is built with a Go backend and a Svelte frontend. It uses SQLite for data storage and provides a RESTful API for communication between the frontend and backend.

## Specification Documents

The following table lists all the specification documents for the QuickNotes application:

| Domain | Description | Link |
|--------|-------------|------|
| Architecture | Overall system architecture | [Architecture](specs/architecture.md) |
| Notes | Note creation, management, and linking | [Notes](specs/notes.md) |
| Readlist | Read later functionality | [Readlist](specs/readlist.md) |
| Feeds | RSS/Atom feed management | [Feeds](specs/feeds.md) |
| Database | Database schema and relationships | [Database](specs/database.md) |
| API | API endpoints and communication | [API](specs/api.md) |
| Frontend | User interface and client-side features | [Frontend](specs/frontend.md) |
| Authentication | User authentication (if applicable) | [Authentication](specs/authentication.md) |
| Emacs Integration | Emacs mode for QuickNotes | [Emacs Integration](specs/emacs_integration.md) |

## Key Features

- Create, edit, and delete notes with Markdown support
- Link notes together using wiki-style `[[note-title]]` syntax
- Visualize note connections with an interactive graph
- Save articles for later reading with automatic content extraction
- Manage and read RSS/Atom feeds
- Import notes from Obsidian vaults
- Emacs integration for accessing QuickNotes features

## Technology Stack

- **Backend**: Go with Gin web framework
- **Frontend**: Svelte with SvelteKit
- **Database**: SQLite with GORM
- **Package Management**: Bun (frontend), Go modules (backend)
- **Testing**: Go testing framework, Playwright for frontend testing 